==> fimex-0.51.tar.gz: fimex-0.51/include/fimex/CDMOverlay.h <==
/* -*- c++ -*-
 * Fimex, CDMOverlay.h
 *
 * (C) Copyright 2012, met.no
 *
 * Project Info:  https://wiki.met.no/fimex/start
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *  Created on: Aug 28, 2012
 *      Author: Alexander Bürger
 */

#ifndef fimex_CDMOverlay_H
#define fimex_CDMOverlay_H 1

#include "fimex/CDMReader.h"
#include "fimex/coordSys/CoordinateSystem.h"
#include "fimex/Data.h"

namespace MetNoFimex {

class CDMOverlayPrivate;

/**
 * @headerfile fimex/CDMOverlay.h
 */
/**
 * Takes two readers, base and top, and returns top when defined, else
 * base. Interpolates top to base's grid.
 * 
 * Used in CDMMerger together with CDMBorderSmoothing, and maybe not
 * very useful elsewhere.
 */
class CDMOverlay : public CDMReader {
public:
    /**
     * Merge data from top grid onto base grid.
     */
    CDMOverlay(boost::shared_ptr<CDMReader> base, boost::shared_ptr<CDMReader> top,
            int gridInterpolationMethod = MIFI_INTERPOL_BILINEAR);

    using CDMReader::getDataSlice;
    virtual boost::shared_ptr<Data> getDataSlice(const std::string &varName, std::size_t unLimDimPos);

private:
    std::auto_ptr<CDMOverlayPrivate> p;
};

typedef boost::shared_ptr<CDMOverlay> CDMOverlayPtr;

} // namespace MetNoFimex

#endif /* fimex_CDMOverlay_H */

==> fimex-0.58.1.tar.gz: fimex-0.58.1/include/fimex/CDMOverlay.h <==
/* -*- c++ -*-
 * Fimex, CDMOverlay.h
 *
 * (C) Copyright 2012, met.no
 *
 * Project Info:  https://wiki.met.no/fimex/start
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *  Created on: Aug 28, 2012
 *      Author: Alexander Bürger
 */

#ifndef fimex_CDMOverlay_H
#define fimex_CDMOverlay_H 1

#include "fimex/CDMReader.h"
#include "fimex/coordSys/CoordinateSystem.h"
#include "fimex/Data.h"

namespace MetNoFimex {

struct CDMOverlayPrivate;

/**
 * @headerfile fimex/CDMOverlay.h
 */
/**
 * Takes two readers, base and top, and returns top when defined, else
 * base. Interpolates top to base's grid.
 *
 * Used in CDMMerger together with CDMBorderSmoothing, and maybe not
 * very useful elsewhere.
 */
class CDMOverlay : public CDMReader {
public:
    /**
     * Merge data from top grid onto base grid.
     */
    CDMOverlay(boost::shared_ptr<CDMReader> base, boost::shared_ptr<CDMReader> top,
            int gridInterpolationMethod = MIFI_INTERPOL_BILINEAR);

    using CDMReader::getDataSlice;
    virtual boost::shared_ptr<Data> getDataSlice(const std::string &varName, std::size_t unLimDimPos);

private:
    std::auto_ptr<CDMOverlayPrivate> p;
};

typedef boost::shared_ptr<CDMOverlay> CDMOverlayPtr;

} // namespace MetNoFimex

#endif /* fimex_CDMOverlay_H */
